import React from 'react';
import ColorPicker from '../../shared/ColorPicker';

type Props = {
  layer: any;
  updatedLayer: any;
  graphInfo: any;
  deleteLayer: any;
};

export default function EdgeOptions({ layer, updatedLayer, graphInfo, deleteLayer }: Props) {
  const [fixedColorMenuOpen, setFixedColorMenuOpen] = React.useState(false);
  const [unfixedColorMenuOpen1, setUnfixedColorMenuOpen1] = React.useState(false);
  const [unfixedColorMenuOpen2, setUnfixedColorMenuOpen2] = React.useState(false);

  return (
    <div>
      <div className="divider m-0"></div>

      <div className="form-control">
        <label className="label cursor-pointer">
          <span className="label-text">Brushing</span>
          <input
            className="checkbox"
            type="checkbox"
            checked={layer.config.brushing.active}
            onChange={(e) =>
              updatedLayer(layer.id, {
                config: {
                  ...layer.config,
                  brushing: {
                    ...layer.config.brushing,
                    active: e.target.checked,
                  },
                },
              })
            }
          />
        </label>
      </div>

      <div>
        {layer.config.brushing.active && (
          <input
            className="range"
            type="range"
            value={layer.config.brushing.radius}
            min={10000}
            max={50000}
            step={1000}
            onChange={(e) =>
              updatedLayer(layer.id, {
                config: {
                  ...layer.config,
                  brushing: {
                    ...layer.config.brushing,
                    radius: e.target.value,
                  },
                },
              })
            }
          />
        )}
      </div>

      <div className="divider m-0"></div>

      <div>
        <p>Color</p>
        <div>
          <div className="form-control">
            <label className="label cursor-pointer">
              <span className="label-text">Fixed</span>
              <input
                className="checkbox"
                type="checkbox"
                checked={layer.config.color.fixed}
                onChange={(e) =>
                  updatedLayer(layer.id, {
                    config: {
                      ...layer.config,
                      color: {
                        ...layer.config.color,
                        fixed: e.target.checked,
                      },
                    },
                  })
                }
              />
            </label>
          </div>
          {layer.config.color.fixed && (
            <ColorPicker
              value={layer.config.color.value}
              updateValue={(newValue: any) =>
                updatedLayer(layer.id, {
                  config: {
                    ...layer.config,
                    color: {
                      ...layer.config.color,
                      value: newValue,
                    },
                  },
                })
              }
            />
          )}

          {!layer.config.color.fixed && (
            <>
              <select
                className="select select-bordered w-full max-w-xs"
                value={layer.config.color.condition}
                onChange={(e) =>
                  updatedLayer(layer.id, {
                    config: {
                      ...layer.config,
                      color: {
                        ...layer.config.color,
                        condition: e.target.value,
                      },
                    },
                  })
                }
              >
                <option disabled selected>
                  Attribute
                </option>
                {Object.keys(graphInfo.edgeAttributes).map((type) => (
                  <option key={type} value={type}>
                    {type}
                  </option>
                ))}
              </select>

              <ColorPicker
                value={layer.config.color.scaleRange[0]}
                updateValue={(newValue: any) =>
                  updatedLayer(layer.id, {
                    config: {
                      ...layer.config,
                      color: {
                        ...layer.config.color,
                        scaleRange: [newValue, layer.config.color.scaleRange[1]],
                      },
                    },
                  })
                }
              />

              <ColorPicker
                value={layer.config.color.scaleRange[1]}
                updateValue={(newValue: any) =>
                  updatedLayer(layer.id, {
                    config: {
                      ...layer.config,
                      color: {
                        ...layer.config.color,
                        scaleRange: [layer.config.color.scaleRange[0], newValue],
                      },
                    },
                  })
                }
              />
            </>
          )}
        </div>
      </div>

      <div className="divider m-0"></div>

      <div>
        <button
          className="btn btn-primary w-full"
          onClick={() =>
            updatedLayer(layer.id, {
              visible: !layer.visible,
            })
          }
        >
          {layer.visible ? 'Hide layer' : 'Show layer'}
        </button>

        <button className="btn btn-outline btn-primar w-full mt-1" onClick={() => deleteLayer(layer.id)}>
          Delete layer
        </button>
      </div>
    </div>
  );
}
